Estimates the covariance matrix of a piecewise deterministic skeleton
EstimateCovarianceMatrix(skeletonList, coordinate = -1L,
zeroMeans = FALSE)a piecewise deterministic skeleton (consisting of Times, Points and Velocities) returned by a sampler
if specified, only estimate the variance of the specified coordinate, otherwise estimate the covariance matrix of all coordinates
if TRUE do not estimate means but assume a centered distribution
Returns a list containing the estimated moment